==> aroundme_0_7_3.tar.gz: aroundme_0_7_3/aroundme/components/core/template/barnraiser_01/inc/menu_structure.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_read'];?>:</span>
	
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "structure") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_structure"<?php echo $link_css;?>><?php echo $lang['menu_policy'];?></a>

<?php
if (isset($_SESSION['user_id'])) {
?>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "ann_list" || $page_name_short == "ann_view") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_ann_list"<?php echo $link_css;?>><?php echo $lang['menu_announcements'];?></a>
<?php }?>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "statistics") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_statistics"<?php echo $link_css;?>><?php echo $lang['menu_statistics'];?></a>

&nbsp;
&#124;
&nbsp;
<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "contact") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_contact"<?php echo $link_css;?>><?php echo $lang['menu_contact'];?></a>

<?php
if (isset($_SESSION['user_id'])) {
?>
	&nbsp;
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_maintain'];?>:</span>
	&nbsp;


	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['maintainer']) {
	$link_css = "";
	if ($page_name_short == "maint_user_list") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_user_list"<?php echo $link_css;?>><?php echo $lang['menu_user'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['permissions']) {
	$link_css = "";
	if ($page_name_short == "maint_permission") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_permission"<?php echo $link_css;?>><?php echo $lang['menu_permissions'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	$link_css = "";
	if ($page_name_short == "maint_system") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_system"<?php echo $link_css;?>><?php echo $lang['menu_system'];?></a>
	&nbsp;
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['mng_contacts']) {
	$link_css = "";
	if ($page_name_short == "maint_contact_list") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_contact_list"<?php echo $link_css;?>><?php echo $lang['menu_contact_reports'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['maintainer']) {
	$link_css = "";
	if ($page_name_short == "maint_location") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_location"<?php echo $link_css;?>><?php echo $lang['menu_location'];?></a>
	<?php }?>
<?php }?>

<br />

==> aroundme_0_7_7.tar.gz: aroundme_0_7_7/aroundme/components/core/template/barnraiser_01/inc/menu_structure.inc.php <==
<?php
// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<span class="txt_highlight"><?php echo $lang['menu_label_read'];?>:</span>
	
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "structure") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_structure"<?php echo $link_css;?>><?php echo $lang['menu_policy'];?></a>

<?php
if (isset($_SESSION['user_id'])) {
?>
	&nbsp;
	
	<?php
	$link_css = "";
	if ($page_name_short == "ann_list" || $page_name_short == "ann_view") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_ann_list"<?php echo $link_css;?>><?php echo $lang['menu_announcements'];?></a>
<?php }?>

&nbsp;

<?php
$link_css = "";
if ($page_name_short == "statistics") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_statistics"<?php echo $link_css;?>><?php echo $lang['menu_statistics'];?></a>

&nbsp;
&#124;
&nbsp;
<span class="txt_highlight"><?php echo $lang['menu_label_do'];?>:</span>
&nbsp;

<?php
$link_css = "";
if ($page_name_short == "contact") {
	$link_css = " class=\"highlight\"";
}
?>
<a href="index.php?amn=core_contact"<?php echo $link_css;?>><?php echo $lang['menu_contact'];?></a>

<?php
if (isset($_SESSION['user_id'])) {
?>
	&nbsp;
	&#124;
	&nbsp;
	<span class="txt_highlight"><?php echo $lang['menu_label_maintain'];?>:</span>
	&nbsp;


	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['maintainer']) {
	$link_css = "";
	if ($page_name_short == "maint_user_list") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_user_list"<?php echo $link_css;?>><?php echo $lang['menu_user'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['permissions']) {
	$link_css = "";
	if ($page_name_short == "maint_permission") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_permission"<?php echo $link_css;?>><?php echo $lang['menu_permissions'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	$link_css = "";
	if ($page_name_short == "maint_system") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_system"<?php echo $link_css;?>><?php echo $lang['menu_system'];?></a>
	&nbsp;
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['mng_contacts']) {
	$link_css = "";
	if ($page_name_short == "maint_contact_list" || $page_name_short == "maint_contact_view") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_contact_list"<?php echo $link_css;?>><?php echo $lang['menu_contact_reports'];?></a>
	&nbsp;
	<?php }?>
	
	<?php
	if ($_SESSION['user_core_permission'] & $resource['user']['maintainer']) {
	$link_css = "";
	if ($page_name_short == "maint_location") {
		$link_css = " class=\"highlight\"";
	}
	?>
	<a href="index.php?amn=core_maint_location"<?php echo $link_css;?>><?php echo $lang['menu_location'];?></a>
	<?php }?>
<?php }?>

<br />
